@@ -1,14 +1,50 @@
+import io
+import logging
 import os
-import sys
+
+import mako.exceptions
+import mako.lookup
+import mako.runtime
+import mako.template
+
+logger = logging.getLogger(__name__)
 
 
-def get_rendered_source_filepath(filepath):
-    dirname = os.path.dirname(filepath)
-    filename = os.path.basename(filepath)
-    return os.path.join(dirname, ".rendered." + filename)
+def run_templating(module_data):
+    module_data["cfg"] = BuildArgs(
+        sources=[],
+        include_dirs=[],
+        extra_compile_args=[],
+        libraries=[],
+        library_dirs=[],
+        extra_link_args=[],
+        dependencies=[],
+        parallel=False,
+    )
+    module_data["setup_pybind11"] = setup_pybind11
+    buf = io.StringIO()
+    ctx = mako.runtime.Context(buf, **module_data)
+
+    filepath = module_data["filepath"]
+    lookup = mako.lookup.TemplateLookup(directories=[os.path.dirname(filepath)])
+    tmpl = mako.template.Template(filename=filepath, lookup=lookup)
+
+    tmpl.render_context(ctx)
+
+    rendered_src_filepath = get_rendered_source_filepath(filepath)
+
+    with open(rendered_src_filepath, "w", newline="") as f:
+        f.write(buf.getvalue())
+
+    module_data["rendered_src_filepath"] = rendered_src_filepath
 
 
 class BuildArgs(dict):
+    """
+    This exists for backwards compatibility with old configuration key names.
+    TODO: Add deprecation warnings to allow removing this sometime in the future.
+    """
+
     _key_mapping = {
         "compiler_args": "extra_compile_args",
         "linker_args": "extra_link_args",
@@ -30,43 +66,7 @@ def setup_pybind11(cfg):
     cfg["compiler_args"] = ["-std=c++11", "-fvisibility=hidden"] + cfg["compiler_args"]
 
 
-def run_templating(module_data):
-    import mako.template
-    import mako.runtime
-    import mako.exceptions
-    import mako.lookup
-
-    if sys.version_info[0] == 2:
-        import StringIO as io
-    else:
-        import io
-
-    module_data["cfg"] = BuildArgs(
-        sources=[],
-        include_dirs=[],
-        extra_compile_args=[],
-        libraries=[],
-        library_dirs=[],
-        extra_link_args=[],
-        dependencies=[],
-        parallel=False,
-    )
-    module_data["setup_pybind11"] = setup_pybind11
-    buf = io.StringIO()
-    ctx = mako.runtime.Context(buf, **module_data)
-
-    filepath = module_data["filepath"]
-    lookup = mako.lookup.TemplateLookup(directories=[os.path.dirname(filepath)])
-    tmpl = mako.template.Template(filename=filepath, lookup=lookup)
-
-    try:
-        tmpl.render_context(ctx)
-    except Exception:
-        print(mako.exceptions.text_error_template().render())
-
-    rendered_src_filepath = get_rendered_source_filepath(filepath)
-
-    with open(rendered_src_filepath, "w", newline="") as f:
-        f.write(buf.getvalue())
-
-    module_data["rendered_src_filepath"] = rendered_src_filepath
+def get_rendered_source_filepath(filepath):
+    dirname = os.path.dirname(filepath)
+    filename = os.path.basename(filepath)
+    return os.path.join(dirname, ".rendered." + filename)
